/*
 * Copyright (c) 2009-2010 Chris Smith
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package uk.co.md87.dsp.extractor.io;

import com.dmdirc.util.MapList;
import com.dmdirc.util.TextFile;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 *
 * @author chris
 */
public class TrainingDataImporter {

    private final TextFile textFile;

    public TrainingDataImporter(final String file) {
        textFile = new TextFile(file);
    }

    public MapList<String, List<float[]>> getTrainingData() throws IOException {
        final MapList<String, List<float[]>> res = new MapList<String, List<float[]>>();

        String activity = null;
        List<float[]> data = null;

        for (String line : textFile.getLines()) {
            if (line.trim().isEmpty()) {
                continue;
            }
            
            if (line.startsWith("Activity: ")) {
                if (activity != null) {
                    res.add(activity, data);
                }

                activity = line.trim().substring(10);
                data = new ArrayList<float[]>(100);
            } else {
                final String[] parts = line.split(":")[1].split(",");
                final float[] values = new float[parts.length];

                for (int i = 0; i < parts.length; i++) {
                    values[i] = Float.parseFloat(parts[i]);
                }

                data.add(values);
            }
        }

        res.add(activity, data);

        return res;
    }

}
